pub fn parse_codex_events(jsonl_path: &Path) -> Result<Vec<ToolInvocation>>Expand description
Parse a Codex event stream into ordered tool invocations.
pub fn parse_codex_events(jsonl_path: &Path) -> Result<Vec<ToolInvocation>>Parse a Codex event stream into ordered tool invocations.