pub struct StagingSection {
pub slug_template: Option<String>,
pub slug_capability: Option<SlugCapability>,
pub stage_name_pattern: Option<String>,
pub stage_name_max_len: Option<usize>,
pub stage_name_invalid_message: Option<String>,
pub rewrites_frontmatter_name: bool,
pub advertises_staged_slug_name: bool,
pub surface_phrase: Option<String>,
pub unresolved_phrase: Option<String>,
}Fields
slug_template: Option<String>slug_capability: Option<SlugCapability>stage_name_pattern: Option<String>stage_name_max_len: Option<usize>stage_name_invalid_message: Option<String>rewrites_frontmatter_name: booladvertises_staged_slug_name: boolsurface_phrase: Option<String>unresolved_phrase: Option<String>Implementations
Sourceimpl StagingSection
impl StagingSection
Sourcepub fn is_configured(&self) -> bool
pub fn is_configured(&self) -> bool
True when any field departs from the defaults — the signal that the descriptor actually configures native staging.