adapter_for

Function adapter_for 

pub fn adapter_for(harness: Harness) -> &'static dyn HarnessAdapter
Resolve the adapter for a Harness. This is the single dispatch point on the harness identifier for all harness-specific behavior; every other module goes through the returned trait object.