Module command_check

Module command_check 

Runner-owned command-check grading.

Structs

CommandCheckCellResult
The result of one environment-matrix cell.
CommandCheckResult
The schema-gated intermediate result persisted before finalize converts it into a normal crate::core::AssertionResult.
CommandCheckSummary

Functions

grade_command_checks
Inject held-out setup files and execute all command checks in declaration order for every matching dispatch task.